@@ -1,12 +1,14 @@
 package App::ProgUtils;
 
-our $DATE = '2017-02-09'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2019-05-18'; # DATE
+our $VERSION = '0.200'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
+our %SPEC;
+
 our $_complete_program = sub {
     require Complete::File;
     require Complete::Program;
@@ -44,6 +46,36 @@ sub _search_program {
     }
 }
 
+$SPEC{list_all_programs_in_path} = {
+    v => 1.1,
+    summary => 'List all programs in PATH',
+    args => {
+        with_path => {
+            schema => 'bool*',
+            cmdline_aliases => {
+                'x' => {is_flag=>1, summary => 'Show path of each program', code => sub { $_[0]{with_path} = 1 }},
+            },
+        },
+    },
+};
+sub list_all_programs_in_path {
+    my %args = @_;
+
+    my $with_path = $args{with_path};
+
+    my @dirs = split(($^O =~ /Win32/ ? qr/;/ : qr/:/), $ENV{PATH});
+    my @all_progs;
+    for my $dir (@dirs) {
+        opendir my($dh), $dir or next;
+        for (readdir($dh)) {
+            push @all_progs, ($with_path ? "$dir/$_" : $_)
+                if !(-d "$dir/$_") && (-x _);
+        }
+    }
+
+    [200, "OK", \@all_progs];
+}
+
 1;
 # ABSTRACT: Command line to manipulate programs in PATH
 
@@ -59,7 +91,7 @@ App::ProgUtils - Command line to manipulate programs in PATH
 
 =head1 VERSION
 
-This document describes version 0.19 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2017-02-09.
+This document describes version 0.200 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2019-05-18.
 
 =head1 SYNOPSIS
 
@@ -68,6 +100,10 @@ programs found in PATH:
 
 =over
 
+=item * L<allprogs>
+
+=item * L<list-all-programs-in-path>
+
 =item * L<progcat>
 
 =item * L<progedit>
@@ -84,6 +120,38 @@ programs found in PATH:
 
 The main feature of these utilities is tab completion.
 
+=head1 FUNCTIONS
+
+
+=head2 list_all_programs_in_path
+
+Usage:
+
+ list_all_programs_in_path(%args) -> [status, msg, payload, meta]
+
+List all programs in PATH.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<with_path> => I<bool>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
 =head1 FAQ
 
 =head2 What is the purpose of this distribution? Haven't other similar utilities existed?
@@ -134,13 +202,15 @@ L<App::ProgUtils>, utilities related to programs.
 
 L<App::WeaverUtils>, utilities related to L<Pod::Weaver>.
 
+L<Complete::Program>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
